@@ -1,5 +1,5 @@
 /* aewm - a minimalist X11 window mananager. vim:sw=4:ts=4:et
- * Copyright 1998-2003 Decklin Foster <decklin@red-bean.com>
+ * Copyright 1998-2004 Decklin Foster <decklin@red-bean.com>
  * This program is free software; see LICENSE for details. */
 
 #include <X11/Xlib.h>
@@ -54,7 +54,7 @@ int main(int argc, char **argv)
             continue;
         }
         /* nothing matched */
-        fprintf(stderr, "usage: aepanel [--config|-rc <file>]\n");
+        fprintf(stderr, "usage: aepanel [--bottom|-b] [--config|-rc <file>]\n");
         exit(2);
     }
 
@@ -162,12 +162,12 @@ void make_client_button(menu_t clients_box, Window w)
 
 void update_client_button(menu_t clients_box, Window w)
 {
-    GtkWidget *button;
+    XPointer button;
     char buf[NAME_SIZE];
 
     if (get_wm_state(w) == WithdrawnState) {
         remove_client_button(w);
-    } else if (XFindContext(dpy, w, client_tab, (XPointer*)&button) == Success) {
+    } else if (XFindContext(dpy, w, client_tab, &button) == Success) {
         get_wm_name(w, buf, sizeof buf);
         gtk_label_set_text(GTK_LABEL(GTK_BIN(button)->child), buf);
     }
@@ -175,10 +175,10 @@ void update_client_button(menu_t clients_box, Window w)
 
 void remove_client_button(Window w)
 {
-    GtkWidget *button;
+    XPointer button;
 
-    if (XFindContext(dpy, w, client_tab, (XPointer*)&button) == Success) {
-        gtk_container_remove(GTK_CONTAINER(clients_box), button);
+    if (XFindContext(dpy, w, client_tab, &button) == Success) {
+        gtk_container_remove(GTK_CONTAINER(clients_box), GTK_WIDGET(button));
         XDeleteContext(dpy, w, client_tab);
     }
 }
