@@ -1,5 +1,5 @@
 /* aewm - a minimalist X11 window mananager. vim:sw=4:ts=4:et
- * Copyright 1998-2003 Decklin Foster <decklin@red-bean.com>
+ * Copyright 1998-2004 Decklin Foster <decklin@red-bean.com>
  * This program is free software; see LICENSE for details. */
 
 #include <X11/StringDefs.h>
@@ -80,8 +80,8 @@ int main(int argc, char **argv)
         commandWidgetClass, cmds_box, NULL);
     XtAddCallback(quit_button,
         XtNcallback, quit_cb, NULL);
-    clients_box = XtCreateManagedWidget("clients",
-        boxWidgetClass, paned, NULL, 0);
+    clients_box = XtVaCreateManagedWidget("clients",
+        boxWidgetClass, paned, NULL);
 
     make_launch_menu(opt_config, launch_menu, add_menu_item, add_sub_menu);
     update_clients(clients_box, root, make_client_button, update_client_button);
@@ -123,23 +123,23 @@ void make_client_button(menu_t clients_box, Window w)
 
 void update_client_button(menu_t clients_box, Window w)
 {
-    Widget button;
+    XPointer button;
     char buf[NAME_SIZE];
 
     if (get_wm_state(w) == WithdrawnState) {
         remove_client_button(w);
-    } else if (XFindContext(dpy, w, client_tab, (XPointer*)&button) == Success) {
+    } else if (XFindContext(dpy, w, client_tab, &button) == Success) {
         get_wm_name(w, buf, sizeof buf);
-        XtVaSetValues(button, XtNlabel, buf, NULL);
+        XtVaSetValues((Widget) button, XtNlabel, buf, NULL);
     }
 }
 
 void remove_client_button(Window w)
 {
-    Widget button;
+    XPointer button;
 
-    if (XFindContext(dpy, w, client_tab, (XPointer*)&button) == Success) {
-        XtDestroyWidget(button);
+    if (XFindContext(dpy, w, client_tab, &button) == Success) {
+        XtDestroyWidget((Widget) button);
         XDeleteContext(dpy, w, client_tab);
     }
 }
