@@ -1,5 +1,5 @@
 /* aewm - a minimalist X11 window mananager. vim:sw=4:ts=4:et
- * Copyright 1998-2003 Decklin Foster <decklin@red-bean.com>
+ * Copyright 1998-2004 Decklin Foster <decklin@red-bean.com>
  * This program is free software; see LICENSE for details. */
 
 #include <stdlib.h>
@@ -99,18 +99,22 @@ void make_launch_menu(char *rcfile, menu_t menu, add_item_func add_item_cb,
     char defrc_buf[BUF_SIZE];
     FILE *rc;
 
-    /* Dijkstra would not have liked this */
-    if (rcfile && (rc = fopen(rcfile, "r"))) goto opened;
-    snprintf(defrc_buf, sizeof defrc_buf, "%s/.aewm/clientsrc", getenv("HOME"));
-    if ((rc = fopen(defrc_buf, "r"))) goto opened;
-    if ((rc = fopen(DEF_RC, "r"))) goto opened;
+    if (rcfile) {
+        rc = fopen(rcfile, "r");
+    } else {
+        snprintf(defrc_buf, sizeof defrc_buf,
+            "%s/.aewm/clientsrc", getenv("HOME"));
+        rc = fopen(defrc_buf, "r");
+        if (!rc) rc = fopen(DEF_RC, "r");
+    }
 
-    fprintf(stderr, "can't find any rc files\n");
-    exit(1);
-
-opened:
-    make_launch_menu_helper(rc, menu, add_item_cb, add_submenu_cb);
-    fclose(rc);
+    if (rc) {
+        make_launch_menu_helper(rc, menu, add_item_cb, add_submenu_cb);
+        fclose(rc);
+    } else {
+        fprintf(stderr, "can't find any rc files\n");
+        exit(1);
+    }
 }
 
 void fork_exec(char *cmd)
@@ -123,6 +127,6 @@ void fork_exec(char *cmd)
             fprintf(stderr, "exec failed, cleaning up child\n");
             exit(1);
         case -1:
-            fprintf(stderr, "can't fork\n"); break;
+            fprintf(stderr, "can't fork\n");
     }
 }
