@@ -1,5 +1,5 @@
 /* aewm - a minimalist X11 window mananager. vim:sw=4:ts=4:et
- * Copyright 1998-2003 Decklin Foster <decklin@red-bean.com>
+ * Copyright 1998-2004 Decklin Foster <decklin@red-bean.com>
  * This program is free software; see LICENSE for details. */
 
 #include <stdio.h>
@@ -17,13 +17,14 @@ XContext client_tab;
 long get_wm_state(Window w)
 {
     Atom real_type; int real_format;
+    long state = WithdrawnState;
     unsigned long items_read, bytes_left;
-    long *data, state = WithdrawnState;
+    unsigned char *data;
 
     if (XGetWindowProperty(dpy, w, wm_state, 0L, 2L, False,
             wm_state, &real_type, &real_format, &items_read, &bytes_left,
-            (unsigned char **) &data) == Success && items_read) {
-        state = *data;
+            &data) == Success && items_read) {
+        state = *(long *)data;
         XFree(data);
     }
     return state;
@@ -41,7 +42,7 @@ void get_wm_name(Window w, char *buf, size_t len)
         strcpy(buf, name);
     } else {
         if (strlen(name) >= len-2) strcpy(name+len-6, "...");
-        sprintf(buf, "(%s)", name);
+        sprintf(buf, "[%s]", name);
     }
 
     XFree(name);
