@@ -1,5 +1,5 @@
 /* aewm - a minimalist X11 window mananager. vim:sw=4:ts=4:et
- * Copyright 1998-2003 Decklin Foster <decklin@red-bean.com>
+ * Copyright 1998-2004 Decklin Foster <decklin@red-bean.com>
  * This program is free software; see LICENSE for details. */
 
 #include "gnome-pda.h"
@@ -13,15 +13,16 @@ int get_gnome_pda(deskarea_t *da)
 {
     Atom real_type; int real_format;
     unsigned long items_read, bytes_left;
-    int *data;
+    unsigned char *data;
 
     if (XGetWindowProperty(dpy, root, gnome_pda, 0L, 4L, False,
             XA_CARDINAL, &real_type, &real_format, &items_read, &bytes_left,
-            (unsigned char **) &data) == Success && items_read) {
-        da->left = data[0];
-        da->right = data[1];
-        da->top = data[2];
-        da->bottom = data[3];
+            &data) == Success && items_read) {
+        int *di = (int *) data;
+        da->left = di[0];
+        da->right = di[1];
+        da->top = di[2];
+        da->bottom = di[3];
         XFree(data);
         return 1;
     } else {
