@@ -1,5 +1,5 @@
 /* aewm - a minimalist X11 window mananager. vim:sw=4:ts=4:et
- * Copyright 1998-2003 Decklin Foster <decklin@red-bean.com>
+ * Copyright 1998-2004 Decklin Foster <decklin@red-bean.com>
  * This program is free software; see LICENSE for details. */
 
 #include <X11/Xmd.h>
@@ -9,10 +9,10 @@ client_t *find_client(Window w, int mode)
 {
     client_t *c;
 
-    if (mode == FRAME) {
+    if (mode == MATCH_FRAME) {
         for (c = head_client; c; c = c->next)
             if (c->frame == w) return c;
-    } else { /* WINDOW */
+    } else if (mode == MATCH_WINDOW) {
         for (c = head_client; c; c = c->next)
             if (c->window == w) return c;
     }
@@ -57,19 +57,20 @@ void set_wm_state(client_t *c, int state)
 /* If we can't find a WM_STATE we're going to have to assume
  * Withdrawn. This is not exactly optimal, since we can't really
  * distinguish between the case where no WM has run yet and when the
- * state was explicitly removed (client_ts are allowed to either set the
+ * state was explicitly removed (clients are allowed to either set the
  * atom to Withdrawn or just remove it... yuck.) */
 
 long get_wm_state(client_t *c)
 {
     Atom real_type; int real_format;
+    long state = WithdrawnState;
     unsigned long items_read, bytes_left;
-    long *data, state = WithdrawnState;
+    unsigned char *data;
 
     if (XGetWindowProperty(dpy, c->window, wm_state, 0L, 2L, False,
             wm_state, &real_type, &real_format, &items_read, &bytes_left,
-            (unsigned char **) &data) == Success && items_read) {
-        state = *data;
+            &data) == Success && items_read) {
+        state = *(long *)data;
         XFree(data);
     }
     return state;
@@ -119,10 +120,10 @@ void remove_client(client_t *c, int mode)
     dump_removal(c, mode);
 #endif
 
-    if (mode == WITHDRAW) set_wm_state(c, WithdrawnState);
-    else /* REMAP */ XMapWindow(dpy, c->window);
+    if (mode == REMOVE_WITHDRAW) set_wm_state(c, WithdrawnState);
+    else if (mode == REMOVE_REMAP) XMapWindow(dpy, c->window);
 
-    gravitate(c, REMOVE_GRAVITY);
+    gravitate(c, GRAV_UNDO);
     XReparentWindow(dpy, c->window, root, c->x, c->y);
 #ifdef MWM_HINTS
     if (c->has_border) XSetWindowBorderWidth(dpy, c->window, 1);
@@ -157,27 +158,27 @@ void remove_client(client_t *c, int mode)
 void redraw(client_t *c)
 {
 #ifdef MWM_HINTS
-	if (!c->has_title) return;
+    if (!c->has_title) return;
 #endif
 
-	XClearWindow(dpy, c->frame);
-	XDrawLine(dpy, c->frame, border_gc,
-		0, theight(c) - BW(c) + BW(c)/2,
-		c->width, theight(c) - BW(c) + BW(c)/2);
-	XDrawLine(dpy, c->frame, border_gc,
-		c->width - theight(c)+ BW(c)/2, 0,
-		c->width - theight(c)+ BW(c)/2, theight(c));
-	if (!c->trans && c->name) {
+    XClearWindow(dpy, c->frame);
+    XDrawLine(dpy, c->frame, border_gc,
+        0, theight(c) - BW(c) + BW(c)/2,
+        c->width, theight(c) - BW(c) + BW(c)/2);
+    XDrawLine(dpy, c->frame, border_gc,
+        c->width - theight(c) + BW(c)/2, 0,
+        c->width - theight(c) + BW(c)/2, theight(c));
+    if (!c->trans && c->name) {
 #ifdef XFT
-		XftDrawString8(c->xftdraw, &xft_fg,
-			xftfont, opt_pad, opt_pad + xftfont->ascent,
-			c->name, strlen(c->name));
+        XftDrawString8(c->xftdraw, &xft_fg,
+            xftfont, opt_pad, opt_pad + xftfont->ascent,
+            c->name, strlen(c->name));
 #else
-		XDrawString(dpy, c->frame, string_gc,
-			opt_pad, opt_pad + font->ascent,
-			c->name, strlen(c->name));
+        XDrawString(dpy, c->frame, string_gc,
+            opt_pad, opt_pad + font->ascent,
+            c->name, strlen(c->name));
 #endif
-	}
+    }
 }
 
 /* Window gravity is a mess to explain, but we don't need to do much
@@ -188,7 +189,7 @@ void redraw(client_t *c)
  * use, but the others should be obvious.) Our titlebar is on the top
  * so we only have to adjust in the first case. */
 
-void gravitate(client_t *c, int multiplier)
+void gravitate(client_t *c, int mode)
 {
     int dy = 0;
     int gravity = (c->size->flags & PWinGravity) ?
@@ -201,7 +202,10 @@ void gravitate(client_t *c, int multiplier)
         case CenterGravity: dy = theight(c)/2; break;
     }
 
-    c->y += multiplier * dy;
+    if (mode == GRAV_APPLY)
+        c->y += dy;
+    else if (mode == GRAV_UNDO)
+        c->y -= dy;
 }
 
 /* Well, the man pages for the shape extension say nothing, but I was
